(this.webpackJsonpst_jsme=this.webpackJsonpst_jsme||[]).push([[0],{17:function(e,t,n){e.exports=n(27)},27:function(e,t,n){"use strict";n.r(t);var l=n(6),a=n.n(l),i=n(14),s=n.n(i),o=n(0),r=n(3),c=n(1),m=n(2),u=n(15),h=n(12),d=function(e){Object(c.a)(n,e);var t=Object(m.a)(n);function n(){var e;Object(o.a)(this,n);for(var l=arguments.length,a=new Array(l),i=0;i<l;i++)a[i]=arguments[i];return(e=t.call.apply(t,[this].concat(a))).state={smile:"Hello"},e}return Object(r.a)(n,[{key:"logSmiles",value:function(e){console.log(e),this.state.smile=e}},{key:"returnSmile",value:function(){h.a.setComponentValue(this.state.smile)}},{key:"render",value:function(){var e=this.props.args,t=e.width,n=e.height,l=e.init_smiles;return a.a.createElement("html",null,a.a.createElement("body",null,a.a.createElement("div",{style:{height:n,marginBottom:"10px"}},a.a.createElement(u.a,{height:n,width:t,smiles:l,options:"oldlook, star",onChange:this.logSmiles.bind(this)})),a.a.createElement("button",{className:"myButton",onClick:this.returnSmile.bind(this)},"Add Molecule")))}}]),n}(h.b),p=Object(h.c)(d);s.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(p,null)),document.getElementById("root"))}},[[17,1,2]]]);
//# sourceMappingURL=main.6ff92f51.chunk.js.map