self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "b77b79cda75ac692237c2a6415057a32",
    "url": "./index.html"
  },
  {
    "revision": "28ad50f2d911996fc7ce",
    "url": "./static/js/2.4ea1358c.chunk.js"
  },
  {
    "revision": "c4806c150d49abac1ee67e2a3f6f71b4",
    "url": "./static/js/2.4ea1358c.chunk.js.LICENSE.txt"
  },
  {
    "revision": "982653f76b599293c73c",
    "url": "./static/js/main.6ff92f51.chunk.js"
  },
  {
    "revision": "7c417fdcdd265b5366e4",
    "url": "./static/js/runtime-main.119b752e.js"
  }
]);